@@ -1,5 +1,5 @@
 /* init.c --- Entry point for libgsasl.
- * Copyright (C) 2002, 2003, 2004, 2005  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -29,10 +29,12 @@
 #include "cram-md5/cram-md5.h"
 #include "external/external.h"
 #include "gssapi/x-gssapi.h"
+#include "gs2/gs2.h"
 #include "anonymous/anonymous.h"
 #include "plain/plain.h"
 #include "securid/securid.h"
 #include "digest-md5/digest-md5.h"
+#include "scram/scram.h"
 
 #include "login/login.h"
 #include "ntlm/x-ntlm.h"
@@ -64,18 +66,18 @@ register_builtin_mechs (Gsasl * ctx)
     return rc;
 #endif /* USE_EXTERNAL */
 
-#ifdef USE_PLAIN
-  rc = gsasl_register (ctx, &gsasl_plain_mechanism);
-  if (rc != GSASL_OK)
-    return rc;
-#endif /* USE_PLAIN */
-
 #ifdef USE_LOGIN
   rc = gsasl_register (ctx, &gsasl_login_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_LOGIN */
 
+#ifdef USE_PLAIN
+  rc = gsasl_register (ctx, &gsasl_plain_mechanism);
+  if (rc != GSASL_OK)
+    return rc;
+#endif /* USE_PLAIN */
+
 #ifdef USE_SECURID
   rc = gsasl_register (ctx, &gsasl_securid_mechanism);
   if (rc != GSASL_OK)
@@ -100,12 +102,24 @@ register_builtin_mechs (Gsasl * ctx)
     return rc;
 #endif /* USE_CRAM_MD5 */
 
+#ifdef USE_SCRAM_SHA1
+  rc = gsasl_register (ctx, &gsasl_scram_sha1_mechanism);
+  if (rc != GSASL_OK)
+    return rc;
+#endif /* USE_SCRAM_SHA1 */
+
 #ifdef USE_GSSAPI
   rc = gsasl_register (ctx, &gsasl_gssapi_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_GSSAPI */
 
+#ifdef USE_GS2
+  rc = gsasl_register (ctx, &gsasl_gs2_krb5_mechanism);
+  if (rc != GSASL_OK)
+    return rc;
+#endif /* USE_GSSAPI */
+
   return GSASL_OK;
 }
 
@@ -118,7 +132,8 @@ register_builtin_mechs (Gsasl * ctx)
  * successful.  It also register all builtin SASL mechanisms, using
  * gsasl_register().
  *
- * Return value: GSASL_OK iff successful, otherwise GSASL_MALLOC_ERROR.
+ * Return value: GSASL_OK iff successful, otherwise
+ * %GSASL_MALLOC_ERROR.
  **/
 int
 gsasl_init (Gsasl ** ctx)
