@@ -24,7 +24,7 @@
 
 #if HAVE_LIBIDN
 # include <stringprep.h>
-# if defined (HAVE_PR29_H) && defined (HAVE_PR29_8Z)
+# if defined HAVE_PR29_H && defined HAVE_PR29_8Z
 #  include <pr29.h>
 # endif
 #endif
@@ -64,7 +64,7 @@ gsasl_saslprep (const char *in, Gsasl_saslprep_flags flags,
       return GSASL_SASLPREP_ERROR;
     }
 
-# if defined (HAVE_PR29_8Z) && defined (HAVE_PR29_H)
+# if defined HAVE_PR29_8Z && defined HAVE_PR29_H
   if (pr29_8z (*out) != PR29_SUCCESS)
     {
       free (*out);
